# -*- coding: utf-8 -*-
# Flask-Diamond (c) Ian Dennis Miller


def init_blueprints(self):
    """
    Initialize blueprints.

    :returns: None

    By default, this function does nothing.  Your application needs to
    overload this function in order to implement your View functionality.
    More information about blueprints can be found in the
    `Flask documentation <http://flask.pocoo.org/docs/0.10/blueprints/>`_.
    """

    from ..views.diamond import diamond_blueprint
    self.app.register_blueprint(diamond_blueprint)
