<!DOCTYPE html>
<html>
<head>
    {% block htmlhead %}{% endblock %}
    <link rel="stylesheet" type="text/css" href="{{ url_for('diamond_blueprint.static', filename='style.css') }}">
    <link rel="icon" type="image/png" href="{{ url_for('diamond_blueprint.static', filename='favicon.ico') }}">
    <title>{% block title %}{% endblock %} - {{ config['PROJECT_NAME'] }}</title>
</head>
<body {% block bodyclass %}{% endblock %}>
  {% block navigation %}{% endblock %}
  {% block heading %}{% endblock %}

  <div id="content">
    {% block content %}{% endblock %}
  </div>

  <div id="footer">
    {% block footer %}
    {{ config['PROJECT_NAME'] }}
    {% endblock %}
  </div>

{% block scripts %}{% endblock %}
</body>
