{% extends "security/base.html" %}

{% block security_content %}
  <div class="page-header">
    <h1>Change your password</h1>
  </div>

  <form class="form form-horizontal" action="{{ url_for_security('change_password') }}" method="POST" name="change_password_form">
    {{ change_password_form.csrf_token }}

    {{ wtf.horizontal_field(change_password_form.password) }}
    {{ wtf.horizontal_field(change_password_form.new_password) }}
    {{ wtf.horizontal_field(change_password_form.new_password_confirm) }}

    <div class="col-lg-offset-2">
      <input type="submit" value="Change password" class="btn btn-primary" />
    </div>
  </form>

{% endblock %}

{% block tail_js %}
  {{ super() }}
  <script type="text/javascript">
    $(function() { $($("#password").focus()); });
  </script>
{% endblock %}
