{% extends "security/base.html" %}

{% block security_content %}
  <div class="alert alert-info alert-dismissable">
    Remembered your password? <a href="{{ url_for_security('login') }}">Try and login</a>
  </div>

  <div class="page-header">
    <h1>Reset your password</h1>
  </div>

  <form class="form form-horizontal" action="{{ url_for_security('reset_password', token=reset_password_token) }}" method="POST" name="reset_password_form">
    {{ reset_password_form.csrf_token }}

    {{ wtf.horizontal_field(reset_password_form.password) }}
    {{ wtf.horizontal_field(reset_password_form.password_confirm) }}

    <div class="col-lg-offset-2">
      <input type="submit" value="Reset password" class="btn btn-primary" />
    </div>
  </form>

  <br />

{% endblock %}
